@@ -2,6 +2,7 @@
 
 import os
 import traceback
+from pathlib import Path
 from typing import cast
 
 import requests
@@ -64,8 +65,11 @@ def is_google_cloud() -> bool:
     # to change), we just don't know the state until we check the first time.
 
     try:
+        timeout = 1.5
         response = requests.get(
-            'http://metadata.google.internal/', timeout=1.5, headers={'Metadata-Flavor': 'Google'},  # noqa: WPS432
+            'http://metadata.google.internal/',
+            timeout=timeout,
+            headers={'Metadata-Flavor': 'Google'},  # noqa: WPS432
         )
         _is_google_cloud = response.status_code == 200  # noqa: WPS432,WPS122,WPS442
     except (requests.exceptions.Timeout, requests.exceptions.ConnectionError):
@@ -110,3 +114,31 @@ def is_ci() -> bool:
         return False
 
     return value in {'1', 'true'}
+
+
+def _in_cgroup(token: str) -> bool:
+    try:
+        with open('/proc/self/cgroup', 'r') as handle:
+            content = handle.read()
+            return token in content
+
+    except Exception:
+        return False
+
+
+def _is_docker_from_cgroup() -> bool:
+    return _in_cgroup('/docker')
+
+
+def _is_docker_dockerenv() -> bool:
+    return Path('/.dockerenv').exists()
+
+
+def is_docker() -> bool:
+    return _is_docker_dockerenv() or _is_docker_from_cgroup()
+
+
+# This is experimental, we only return True if we're sure
+# but we could have false negatives
+def is_docker_build() -> bool:
+    return _in_cgroup('/docker/buildkit')
