@@ -5,11 +5,12 @@ import warnings
 from enum import Enum
 from typing import Dict, Literal, Optional, Protocol, Union
 
-from outcome.utils import env
-from outcome.utils.config import Config
 from rich.console import Console
 from rich.table import Table
 
+from outcome.utils import env
+from outcome.utils.config import Config
+
 StateSource = Literal['config', 'default']
 
 
@@ -30,9 +31,9 @@ class FeatureType(Enum):
 _feature_pattern = '^[a-z]+(_?[a-z]+_?[a-z])*$'
 _feature_prefix = 'WITH_FEAT_'
 
-_features: Dict[str, Union[bool, str, None]]
-_feature_types: Dict[str, FeatureType]
-_config: Config
+_features: Dict[str, Union[bool, str, None]] = {}
+_feature_types: Dict[str, FeatureType] = {}
+_config: Config = Config()
 
 
 def reset():
@@ -64,7 +65,9 @@ def set_config(config: Config) -> None:
 
 
 def register_feature(
-    feature: str, default: Optional[Union[bool, str]] = None, feature_type: FeatureType = FeatureType.boolean,
+    feature: str,
+    default: Optional[Union[bool, str]] = None,
+    feature_type: FeatureType = FeatureType.boolean,
 ) -> None:
     if not _is_valid_feature_name(feature):
         raise FeatureException(f'Invalid feature name: {feature}')
