@@ -1,10 +1,13 @@
 """Load objects from a mod:obj path."""
 
-from importlib import import_module, util  # pragma: no cover
-from typing import Optional
+from importlib import import_module, util
+from types import ModuleType  # pragma: no cover
+from typing import Optional, Type, TypeVar, cast
+
+T = TypeVar('T')
 
 
-def load_obj(objspec: str, default_obj: Optional[str] = None):
+def load_obj(objspec: str, default_obj: Optional[str] = None, *, t: Type[T] = object) -> T:
     parts = objspec.split(':')
     modname = None
     objname = None
@@ -19,12 +22,14 @@ def load_obj(objspec: str, default_obj: Optional[str] = None):
     if not (modname and objname):
         raise ValueError(f'Invalid objspec: {objspec}')
 
-    return getattr(import_module(modname), objname)
+    o = getattr(import_module(modname), objname)
+
+    return cast(T, o)
 
 
-def load_module(name: str, path: str):  # pragma: no cover
+def load_module(name: str, path: str, *, t: Type[T] = ModuleType) -> T:  # pragma: no cover
     spec = util.spec_from_file_location(name, path)
     mod = util.module_from_spec(spec)
     assert spec.loader
     spec.loader.exec_module(mod)  # type: ignore
-    return mod
+    return cast(T, mod)
