@@ -28,9 +28,9 @@ from contextlib import contextmanager
 from contextvars import ContextVar
 from enum import Enum
 from types import TracebackType
-from typing import Callable, Generic, Iterator, List, Optional, Type, TypeVar
+from typing import Callable, Generic, Iterator, List, Optional, Type, TypeVar, cast
 
-txns = ContextVar('txns', default=[])
+txns = ContextVar('txns', default=cast(List['Transaction'], []))
 
 
 def reset_context():  # pragma: no cover
